@@ -4,12 +4,18 @@ import json
 import click
 
 from kiraak.main import main
+from kiraak.config import Config, API
 
 
 @click.command()
 @click.argument("json_file", type=click.Path(exists=True, dir_okay=False))
-def cli(json_file: str) -> None:
+@click.option("--clear", is_flag=True)
+def cli(json_file: str, clear) -> None:
     """Initiates cli"""
+    if clear:  # Clear cached login data
+        Config.CONF_FILE.unlink()
+        API.TOKEN_FILE.unlink()
+
     if not json_file.endswith(".json"):
         click.echo("File must be a JSON file (.json)!")
         raise click.Abort()
@@ -19,5 +25,6 @@ def cli(json_file: str) -> None:
     except json.JSONDecodeError as err:
         click.echo("File must be a valid JSON file!")
         raise click.Abort() from err
+
     click.echo(f"Adding orders from {json_file}")
     main(json_file)
