@@ -34,7 +34,7 @@ class Config:
         CONF_FILE = pathlib.Path(os.path.expanduser("~/.config/kiraakapi/conf.json"))
     else:
         CONF_FILE = pathlib.Path(
-            os.path.expandvars("%APPDATA%/Roaming/kiraakapi/conf.json")
+            os.path.expandvars("%APPDATA%/kiraakapi/conf.json")
         )
     if CONF_FILE.exists():
         with CONF_FILE.open("r") as f:
