@@ -1,4 +1,4 @@
-"""Processing of excel file and adding orders"""
+"""Processing of json file and adding orders"""
 import logging
 
 from openpyxl import Workbook
